"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const glob = require("glob");
const fs_1 = require("fs");
async function replaceTemplateFiles(workingDirectory) {
    return new Promise((resolve, reject) => {
        glob(`${workingDirectory}/**/*.template`, { dot: true }, (err, files) => {
            for (const i in files) {
                const file = files[i];
                fs_1.renameSync(file, file.replace('.template', ''));
            }
        });
    });
}
async function createProject(opts) {
    if (!opts.npmPackage || !opts.npmPackage.name) {
        throw new Error('npmPackage.name argument required');
    }
    if (!opts.workingDirectory) {
        throw new Error('workingDirectory argument required');
    }
    // Extract the content from npmjs.com
    await utils_1.npm.extractPackageContent(opts.workingDirectory, opts.npmPackage.name, opts.npmPackage.version);
    // Replace
    await replaceTemplateFiles(opts.workingDirectory);
    // Create the git repository and commit new changes
    await utils_1.git.initRepository(opts.workingDirectory);
    await utils_1.git.commitChanges(opts.workingDirectory, 'Initial commit');
    return true;
}
exports.createProject = createProject;
//# sourceMappingURL=index.js.map